@@ -1,4 +1,6 @@
-load File.dirname(__FILE__) / ".." / "tag_helpers.rb"
+#load File.dirname(__FILE__) / ".." / "tag_helpers.rb"
+
+require 'merb-helpers/tag_helpers'
 
 module Merb::Helpers::Form::Builder
 
@@ -116,7 +118,7 @@ module Merb::Helpers::Form::Builder
 
     def submit(value, attrs)
       attrs[:type]  ||= "submit"
-      attrs[:name]  ||= "submit"
+      attrs[:name]  ||= "form_submit"
       attrs[:value] ||= value
       update_unbound_controls(attrs, "submit")
       self_closing_tag(:input, attrs)
@@ -131,7 +133,7 @@ module Merb::Helpers::Form::Builder
       attrs[:method] = :post unless attrs[:method] == :get
       # Use a fake PUT if the object is not new, otherwise use the method
       # passed in. Defaults to :post if no method is set.
-      method ||= (@obj.respond_to?(:new?) && !@obj.new?) || (@obj.respond_to?(:new_record?) && !@obj.new_record?) ? :put : :post
+      method ||= (@obj.respond_to?(:new_record?) && !@obj.new_record?) ? :put : :post
 
       attrs[:enctype] = "multipart/form-data" if attrs.delete(:multipart) || @multipart
 
@@ -140,7 +142,7 @@ module Merb::Helpers::Form::Builder
 
     # This can be overridden to use another method to fake out methods
     def fake_out_method(attrs, method)
-      self_closing_tag(:input, :type => "hidden", :name => "_method", :value => method)
+      unbound_hidden_field(:name => "_method", :value => method)
     end
 
     def update_bound_controls(method, attrs, type)
@@ -260,9 +262,9 @@ module Merb::Helpers::Form::Builder
 
         option_attrs = {:value => value}
         if sel.is_a?(Array)
-          option_attrs.merge!(:selected => "selected") if value.in? sel
+          option_attrs.merge!(:selected => "selected") if value.in? sel.map {|e| e.to_s }
         else
-          option_attrs.merge!(:selected => "selected") if value == sel
+          option_attrs.merge!(:selected => "selected") if value == sel.to_s
         end
         tag(:option, text, option_attrs)
       end).join
@@ -375,8 +377,7 @@ module Merb::Helpers::Form::Builder
 
     def update_unbound_controls(attrs, type)
       if attrs[:name] && !attrs[:id]
-        # '[' and ']' are illegal in HTML id attributes
-        attrs.merge!(:id => attrs[:name].to_s.gsub(/(\[|\])/, '_'))
+        attrs.merge!(:id => valid_xhtml_id(attrs[:name]))
       end
       case type
       when "text", "radio", "password", "hidden", "checkbox", "file"
@@ -385,6 +386,10 @@ module Merb::Helpers::Form::Builder
       super
     end
 
+    def valid_xhtml_id(candidate)
+      candidate.to_s.gsub(/(\[|\])/, '_')
+    end
+
     def radio_group_item(method, attrs)
       unless attrs[:id]
         attrs.merge!(:id => "#{@name}_#{method}_#{attrs[:value]}")
@@ -400,21 +405,20 @@ module Merb::Helpers::Form::Builder
       obj ||= @obj
       return "" unless obj.respond_to?(:errors)
 
-      sequel = !obj.errors.respond_to?(:each)
-      errors = sequel ? obj.errors.full_messages : obj.errors
+      errors = obj.errors
 
       return "" if errors.empty?
 
       header_message = header % [errors.size, errors.size == 1 ? "" : "s"]
       markup = %Q{<div class='#{error_class}'>#{header_message}<ul>}
-      errors.each {|err| markup << (build_li % (sequel ? err : err.join(" ")))}
+      errors.each {|err| markup << (build_li % err.join(" "))}
       markup << %Q{</ul></div>}
     end
 
     private
 
     def update_bound_controls(method, attrs, type)
-      if @obj && !@obj.errors.on(method.to_sym).blank?
+      if @obj && !@obj.errors[method.to_sym].blank?
         add_css_class(attrs, "error")
       end
       super
