@@ -1,4 +1,4 @@
-require File.dirname(__FILE__) + '/spec_helper'
+require 'spec_helper'
 
 # Quick rundown of how these specs work
 # please read before hacking on this plugin
@@ -49,8 +49,7 @@ describe "error_messages_for" do
     @dm_obj = Object.new
     @sq_obj = Object.new
     @dm_errors = [["foo", "bar"],["baz","bat"]]
-    @sq_errors = Object.new
-    @sq_errors.stub!(:full_messages).and_return(["foo", "baz"])
+    @sq_errors = {:foo => ["bar"],:baz => ["bat"]}
     @dm_obj.stub!(:errors).and_return(@dm_errors)
     @dm_obj.stub!(:new_record?).and_return(false)
     @sq_obj.stub!(:errors).and_return(@sq_errors)
@@ -67,8 +66,8 @@ describe "error_messages_for" do
   it "should build default error messages for Sequel-like models" do
     errs = @c.error_messages_for(@sq_obj)
     errs.should include("<h2>Form submission failed because of 2 problems</h2>")
-    errs.should include("<li>foo</li>")
-    errs.should include("<li>baz</li>")
+    errs.should include("<li>foo bar</li>")
+    errs.should include("<li>baz bat</li>")
   end
 
   # it "should build default error messages for symbol" do
@@ -132,13 +131,13 @@ describe "form" do
   it "should fake out the put method if set" do
     ret = @c.render(:fake_put_if_set)
     ret.should have_selector("form[method=post]")
-    ret.should have_selector("input[type=hidden][name=_method][value=put]")
+    ret.should have_selector("input[type=hidden][name=_method][value=put][class=hidden]")
   end
 
   it "should fake out the delete method if set" do
     ret = @c.render(:fake_delete_if_set)
     ret.should have_selector("form[method=post]")
-    ret.should have_selector("input[type=hidden][name=_method][value=delete]")
+    ret.should have_selector("input[type=hidden][name=_method][value=delete][class=hidden]")
   end
 
   # TODO: Why is this required?
@@ -187,6 +186,13 @@ describe "form_for" do
     form.should_not have_selector("input[type=hidden][name=_method]")
   end
 
+  it "should use POST if the object passed in is nil" do
+    @c.instance_variable_set(:@obj, nil)
+    form = @c.render :advanced
+    form.should have_selector("form[method=post]")
+    form.should_not have_selector("input[type=hidden][value=put][name=_method]")
+  end
+
   it "should support PUT if the object passed in is not a new_record? via a hidden field" do
     form = @c.render :basic
     form.should have_selector("form[method=post]")
@@ -226,6 +232,13 @@ describe "fields_for" do
     r = @c.render :midstream
     r.should have_selector("input[id=fake_model_foo][name='fake_model[foo]'][type=text][extra=true]")
   end
+
+  it "should be able to handle namespaced models by setting name attribute to concrete class name" do
+    @c.instance_variable_set(:@obj2, MyNamespace::NamespacedFakeModel.new)
+    r = @c.render :midstream
+    r.should have_selector("input[type=text][value=foowee]")
+    r.should have_selector("input[name='namespaced_fake_model[foo]'][type=text][value=named_foo]")
+  end
 end
 
 describe "text_field" do
@@ -273,6 +286,12 @@ describe "bound_text_field" do
     r.should have_selector("input[type=text][id=fake_model_foo][name='fake_model[foo]'][value=foowee]")
   end
 
+  it "should take a namespaced model and return correct fieldname" do
+    @c.instance_variable_set(:@obj, MyNamespace::NamespacedFakeModel.new)
+    r = @c.render :basic
+    r.should have_selector("input[type=text][id=namespaced_fake_model_foo][name='namespaced_fake_model[foo]'][value=named_foo]")
+  end
+
   it "should take additional attributes and use them" do
     r = @c.render :basic
     r.should have_selector("input[type=text][name='fake_model[foo]'][value=foowee][bar='7']")
@@ -300,7 +319,7 @@ describe "bound_text_field" do
     model.stub!(:class).and_return("MyClass")
     model.stub!(:foo).and_return("FOO")
     errors = mock("errors")
-    errors.should_receive(:on).with(:foo).and_return(true)
+    errors.should_receive(:[]).with(:foo).and_return(true)
 
     model.stub!(:errors).and_return(errors)
     @c.instance_variable_set(:@obj, model)
@@ -348,7 +367,7 @@ describe "bound_radio_button" do
     model.stub!(:class).and_return("MyClass")
     model.stub!(:foo).and_return("FOO")
     errors = mock("errors")
-    errors.should_receive(:on).with(:foo).and_return(true)
+    errors.should_receive(:[]).with(:foo).and_return(true)
 
     model.stub!(:errors).and_return(errors)
     @c.instance_variable_set(:@obj, model)
@@ -419,7 +438,7 @@ describe "bound_password_field" do
     model.stub!(:class).and_return("MyClass")
     model.stub!(:foo).and_return("FOO")
     errors = mock("errors")
-    errors.should_receive(:on).with(:foo).and_return(true)
+    errors.should_receive(:[]).with(:foo).and_return(true)
 
     model.stub!(:errors).and_return(errors)
 
@@ -583,8 +602,8 @@ describe "bound_check_box" do
     model.stub!(:baz).and_return("BAZ")
     model.stub!(:bat).and_return("BAT")
     errors = mock("errors")
-    errors.should_receive(:on).with(:baz).and_return(true)
-    errors.should_receive(:on).with(:bat).and_return(true)
+    errors.should_receive(:[]).with(:baz).and_return(true)
+    errors.should_receive(:[]).with(:bat).and_return(true)
 
     model.stub!(:errors).and_return(errors)
 
@@ -619,11 +638,16 @@ describe "hidden_field" do
     @c = HiddenFieldSpecs.new(Merb::Request.new({}))
   end
 
-  it "should return a basic checkbox based on the values passed in" do
+  it "should return a basic hidden field based on the values passed in" do
     r = @c.render :basic
     r.should match_tag(:input, :type => "hidden", :id => "foo", :name => "foo", :value => "bar")
   end
 
+  it "should have class 'hidden' by default" do
+    r = @c.render :basic
+    r.should match_tag(:input, :type => "hidden", :class => 'hidden')
+  end
+
   it "should not render a label if the :label option is passed in" do
     res = @c.render :label
     res.should_not match(/<label>LABEL/)
@@ -670,7 +694,7 @@ describe "bound_hidden_field" do
     model.stub!(:class).and_return("MyClass")
     model.stub!(:foo).and_return("FOO")
     errors = mock("errors")
-    errors.should_receive(:on).with(:foo).and_return(true)
+    errors.should_receive(:[]).with(:foo).and_return(true)
 
     model.stub!(:errors).and_return(errors)
 
@@ -788,7 +812,6 @@ describe "bound_radio_group" do
     r = @c.render :basic
     r.should match_tag(:input, :type => "radio", :id => "fake_model_foo_foowee", :name => "fake_model[foo]", :value => "foowee", :checked => "checked")
     r.should match_tag(:input, :type => "radio", :id => "fake_model_foo_baree", :name => "fake_model[foo]", :value => "baree")
-    r.should_not match_tag(:checked => "checked")
   end
 
   it "should provide an additional label tag for each option in array-based options" do
@@ -914,13 +937,33 @@ describe "select" do
     r.should have_selector("select[name=foo] option:contains('three')")
   end
   
-  it "should allow selecting an option by passing in :selected => 'three'" do
+  it "should allow selecting an option by passing in :selected => string" do
+    @c.instance_variable_set(:@collection, %w(one two three))
+    @c.instance_variable_set(:@selected, 'three')
     r = @c.render :selected
     r.should_not have_selector("select[name=foo] option[selected]:contains('one')")
     r.should_not have_selector("select[name=foo] option[selected]:contains('two')")
     r.should have_selector("select[name=foo] option[selected]:contains('three')")
   end
 
+  it "should allow selecting an option by passing in :selected => integer" do
+    @c.instance_variable_set(:@collection, %w(1 2 3))
+    @c.instance_variable_set(:@selected, 3)
+    r = @c.render :selected
+    r.should_not have_selector("select[name=foo] option[selected]:contains('1')")
+    r.should_not have_selector("select[name=foo] option[selected]:contains('2')")
+    r.should have_selector("select[name=foo] option[selected]:contains('3')")
+  end
+
+  it "should allow selecting an option by passing in :selected => [integers]" do
+    @c.instance_variable_set(:@collection, %w(1 2 3))
+    @c.instance_variable_set(:@selected, [2, 3])
+    r = @c.render :selected
+    r.should_not have_selector("select[name=foo] option[selected]:contains('1')")
+    r.should have_selector("select[name=foo] option[selected]:contains('2')")
+    r.should have_selector("select[name=foo] option[selected]:contains('3')")
+  end
+
   it "should render the select tag with suffix '[]' to name when :multiple => true" do
     r = @c.render :multiple
     r.should match_tag( :select, :name => "foo[]")
@@ -1093,7 +1136,7 @@ describe "option tags" do
   it "should provide selected options by value" do
     r = @c.render :selected
     r.should match_tag( :option, :value => 'rabbit', :selected => 'selected', :content => 'Rabbit' )
-    r.should_not match_tag( :option, :value => 'chicken', :selected => '', :content => 'Chicken' )
+    r.should_not match_tag( :option, :value => 'chicken', :selected => 'nil', :content => 'Chicken' )
   end
 
   it "should handle arrays for selected when :multiple is true" do
@@ -1228,7 +1271,7 @@ describe "submit" do
 
   it "should provide an additional label tag if the :label option is passed in" do
     r = @c.render :submit_with_label
-    r.should have_selector("input[type=submit][name=submit][value=Done]")
+    r.should have_selector("input[type=submit][name=form_submit][value=Done]")
     r.should have_selector("label:contains('LABEL')")
   end
 
@@ -1379,4 +1422,4 @@ describe "escaping values" do
     r.should =~ /&amp;&quot;&lt;&gt;/
   end
 
-end
\ No newline at end of file
+end
